@@ -1,8 +1,7 @@
 package Bio::Phylo;
 use strict;
-use base 'Bio::Phylo::Identifiable';
-
-# ABSTRACT: Phyloinformatic analysis using Perl
+use Bio::PhyloRole;
+use base 'Bio::PhyloRole';
 
 # Because we use a roll-your-own looks_like_number from
 # Bio::Phylo::Util::CONSTANT, here we don't have to worry
@@ -13,21 +12,19 @@ use Scalar::Util qw'weaken blessed';
 # in one location, perhaps using the S::U version, or a drop-in
 use Bio::Phylo::Util::CONSTANT '/looks_like/';
 use Bio::Phylo::Util::IDPool;    # creates unique object IDs
-use Bio::Phylo::Identifiable;    # for storing unique IDs inside an instance
 use Bio::Phylo::Util::Exceptions 'throw'; # defines exception classes and throws
 use Bio::Phylo::Util::Logger;             # for logging, like log4perl/log4j
+use Bio::Phylo::Identifiable;    # for storing unique IDs inside an instance
+
 our ( $logger, $COMPAT ) = Bio::Phylo::Util::Logger->new;
+our $VERSION = "0.51";
 
 # mediates one-to-many relationships between taxon and nodes,
 # taxon and sequences, taxa and forests, taxa and matrices.
 # Read up on the Mediator design pattern to learn how this works.
 require Bio::Phylo::Mediators::TaxaMediator;
 
-# Include the revision number from subversion in $VERSION
-my $rev = '$Id: Phylo.pm 1660 2011-04-02 18:29:40Z rvos $';
-$rev =~ s/^[^\d]+(\d+)\b.*$/$1/;
-our $VERSION = "0.50";
-$VERSION .= "_$rev";
+
 {
     my $taxamediator = 'Bio::Phylo::Mediators::TaxaMediator';
 
@@ -43,8 +40,7 @@ $VERSION .= "_$rev";
                     $COMPAT = ucfirst( lc($value) );
                 }
                 else {
-                    throw 'BadArgs' =>
-                      "'$key' is not a valid argument for import";
+                    throw 'BadArgs' => "'$key' is not a valid argument for import";
                 }
             }
         }
@@ -188,8 +184,7 @@ argument "-name" in the constructor.
                 }
 
                 # notify user
-                $logger->debug(
-                    "processing constructor arg '${key}' => '${value}'");
+                $logger->debug("processing constructor arg '${key}' => '${value}'");
 
                 # don't access data structures directly, call mutators
                 # in child classes or __PACKAGE__
@@ -204,11 +199,8 @@ argument "-name" in the constructor.
                     if ( blessed $@ and $@->can('rethrow') ) {
                         $@->rethrow;
                     }
-                    elsif ( not ref($@)
-                        and $@ =~ /^Can't locate object method / )
-                    {
-                        throw 'BadArgs' =>
-"The named argument '${key}' cannot be passed to the constructor of ${class}";
+                    elsif ( not ref($@) and $@ =~ /^Can't locate object method / ) {
+                        throw 'BadArgs' => "The named argument '${key}' cannot be passed to the constructor of ${class}";
                     }
                     else {
                         throw 'Generic' => $@;
@@ -341,7 +333,7 @@ Sets generic key/value pair(s).
         # retrieve id just once, don't call $self->get_id in loops, inefficient
         my $id = $self->get_id;
 
-     # this initializes the hash if it didn't exist yet, or resets it if no args
+		# this initializes the hash if it didn't exist yet, or resets it if no args
         if ( !defined $generic{$id} || !@_ ) {
             $generic{$id} = {};
         }
@@ -377,77 +369,6 @@ Sets generic key/value pair(s).
 
 =over
 
-=item get_nexus_name()
-
-Gets invocant's name, modified to be safely used in nexus files. This means that:
-
-=item * 
-
-names with spaces in them that aren't 'single quoted' have their spaces replaced
-with underscores
-
-=item * 
-
-names with any of the following characters in them are single quoted: 
- -^*(){}[]+=;:"\<>/,
-
-=item * 
-
-names with single quotes inside them (i.e. not around them) are "double quoted"
-
- Type    : Accessor
- Title   : get_nexus_name
- Usage   : my $name = $obj->get_nexus_name;
- Function: Returns the object's name.
- Returns : A string
- Args    : None
-
-=cut
-
-    sub get_nexus_name {
-        my $self = shift;
-        my $name = $self->get_internal_name;
-        if ( $name =~ /\s/ && $name !~ /^'.+'$/ ) {
-            $name =~ s/\s/_/g;
-        }
-        if (   $name =~ /(?:\-|\^|\*|\(|\)|{|}|\[|\]|\+|=|;|:|"|\\|<|>|\/|,)/
-            && $name !~ /^'.+'$/ )
-        {
-            $name = "'${name}'";
-        }
-        if ( $name =~ /'/ && $name !~ /^".+"$/ && $name !~ /^'.+'$/ ) {
-            $name = "\"${name}\"";
-        }
-        return $name;
-    }
-
-=item get_internal_name()
-
-Gets invocant's 'fallback' name (possibly autogenerated).
-
- Type    : Accessor
- Title   : get_internal_name
- Usage   : my $name = $obj->get_internal_name;
- Function: Returns the object's name (if none was set, the name
-           is a combination of the $obj's class and its UID).
- Returns : A string
- Args    : None
-
-=cut
-
-    sub get_internal_name {
-        my $self = shift;
-        if ( my $name = $self->get_name ) {
-            return $name;
-        }
-        else {
-            my $internal_name = ref $self;
-            $internal_name =~ s/.*:://;
-            $internal_name .= $self->get_id;
-            return $internal_name;
-        }
-    }
-
 =item get_guid()
 
 Gets invocant GUID.
@@ -465,8 +386,8 @@ Gets invocant GUID.
 =cut
 
     sub get_guid {
-	my $self = shift;
-	return $guid{ $self->get_id };
+		my $self = shift;
+		return $guid{ $self->get_id };
     }
 
 =item get_desc()
@@ -502,7 +423,6 @@ Gets invocant's score.
 
     sub get_score {
         my $self = shift;
-        $logger->debug("getting score");
         return $score{ $self->get_id };
     }
 
@@ -559,56 +479,12 @@ Gets generic hashref or hash value(s).
         }
     }
 
-=item get_logger()
-
-Gets a logger object.
-
- Type    : Accessor
- Title   : get_logger
- Usage   : my $logger = $obj->get_logger;
- Function: Returns a Bio::Phylo::Util::Logger object
- Returns : Bio::Phylo::Util::Logger
- Args    : None
-
-=cut
-
-    sub get_logger { $logger }
-
 =back
 
 =head2 PACKAGE METHODS
 
 =over
 
-=item get()
-
-Attempts to execute argument string as method on invocant.
-
- Type    : Accessor
- Title   : get
- Usage   : my $treename = $tree->get('get_name');
- Function: Alternative syntax for safely accessing
-           any of the object data; useful for
-           interpolating runtime $vars.
- Returns : (context dependent)
- Args    : a SCALAR variable, e.g. $var = 'get_name';
-
-=cut
-
-    sub get {
-        my ( $self, $var ) = @_;
-        if ( $self->can($var) ) {
-
-            # notify user
-            $logger->debug("retrieving return value for method '$var'");
-            return $self->$var;
-        }
-        else {
-            my $ref = ref $self;
-            throw 'UnknownMethod' => "sorry, a '$ref' can't '$var'";
-        }
-    }
-
 =item get_obj_by_id()
 
 Attempts to fetch an in-memory object by its UID
@@ -627,38 +503,6 @@ Attempts to fetch an in-memory object by its UID
         return $objects{$id};
     }
 
-=item to_string()
-
-Serializes object to general purpose string
-
- Type    : Serializer
- Title   : to_string()
- Usage   : print $obj->to_string();
- Function: Serializes object to general purpose string
- Returns : String 
- Args    : None
- Comments: This is YAML
-
-=cut
-
-    sub to_string {
-        my $self          = shift;
-        my $class         = ref $self;
-        my $id            = $self->get_id;
-        my $internal_name = $self->get_internal_name;
-        my $name          = $self->get_name;
-        my $score         = $self->get_score;
-        my $desc          = $self->get_desc;
-        return <<"SERIALIZED_OBJECT";
-class: $class
-id: $id
-internal_name: $internal_name
-name: $name
-score: $score
-desc: $desc
-SERIALIZED_OBJECT
-    }
-
 =item clone()
 
 Clones invocant.
@@ -717,6 +561,10 @@ Clones invocant.
             delete $subs{'new'};
         }
         my $clone = $class->new(@new);
+		
+        # execute additional code refs
+        $_->( $self, $clone )
+          for ( grep { looks_like_instance( $_, 'CODE' ) } values %subs );		
 
         # populate the clone
         for my $getter ( keys %methods ) {
@@ -742,83 +590,9 @@ Clones invocant.
             }
         }
 
-        # execute additional code refs
-        $_->( $self, $clone )
-          for ( grep { looks_like_instance( $_, 'CODE' ) } values %subs );
         return $clone;
     }
 
-=item VERBOSE()
-
-Getter and setter for the verbosity level. Refer to L<Bio::Phylo::Util::Logger> for more
-info on available verbosity levels.
-
- Type    : Accessor
- Title   : VERBOSE()
- Usage   : Bio::Phylo->VERBOSE( -level => $level )
- Function: Sets/gets verbose level
- Returns : Verbose level
- Args    : -level => $level
- Comments:
-
-=cut
-
-    # Verbosity is mostly handled by the logger, actually. This method
-    # is just here for backward compatibility (and ease of use).
-    # TODO have a facility to turn log levels (warn/error/fatal) into
-    # throws
-    sub VERBOSE {
-        my $class = shift;
-        if (@_) {
-            my %opt = looks_like_hash @_;
-            $logger->VERBOSE(%opt);
-
-            # notify user
-            $logger->info("Changed verbosity level to '$opt{-level}'");
-        }
-        return $Bio::Phylo::Util::Logger::VERBOSE;
-    }
-
-=item CITATION()
-
-Returns suggested citation.
-
- Type    : Accessor
- Title   : CITATION
- Usage   : $phylo->CITATION;
- Function: Returns suggested citation.
- Returns : Returns suggested citation.
- Args    : None
- Comments:
-
-=cut
-
-    sub CITATION {
-        return <<'CITATION';
-Rutger A Vos, Jason Caravas, Klaas Hartmann, Mark A Jensen and Chase Miller, 2011.
-Bio::Phylo - phyloinformatic analysis using Perl. BMC Bioinformatics 12:63.
-doi:10.1186/1471-2105-12-63
-CITATION
-    }
-
-=item VERSION()
-
-Gets version number (including revision number).
-
- Type    : Accessor
- Title   : VERSION
- Usage   : $phylo->VERSION;
- Function: Returns version number
-           (including SVN revision number).
- Alias   :
- Returns : SCALAR
- Args    : NONE
- Comments:
-
-=cut
-
-    sub VERSION { $VERSION }
-
 =begin comment
 
 Invocant destructor.
@@ -905,8 +679,6 @@ Invocant destructor.
     # be inside-out objects).
     sub _cleanup {
         my $self = shift;
-
-        #$logger->debug("cleaning up '$self'"); # XXX
         my $id = $self->get_id;
 
         # cleanup local fields
